Injector class
- Inheritance
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call<
T> () → T -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
Type type, IProvider provider) → void -
override
-
resolve(
Type type) → Object? -
override
-
resolve<
T> () → T? -
Available on IInjector, provided by the InjectorExtensions extension
-
toFactory(
Type api, InjectorFunction factory) → void -
Available on IInjector, provided by the InjectorExtensions extension
-
toSingleton(
Type api, InjectorFunction factory) → void -
Available on IInjector, provided by the InjectorExtensions extension
-
toString(
) → String -
A string representation of this object.
inherited
-
toValue(
{Type? api, required Object value}) → void -
Available on IInjector, provided by the InjectorExtensions extension
-
unregister(
Type type, IProvider provider) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited